﻿//+-------------------------------------------------------------------------------------+
//| ParserIni.h: заголовочный файл экспортируемых функций библиотеки "ParserIni.dll".   |
//| Библиотека функций работы с INI-файлом.                                             |
//| Copyright © 2013, Жунко Вадим (Zhunko)                                              |
//| e-mail: vadim@zhunko.ru                                     30.09.2013 - 11.02.2014 |
//+-------------------------------------------------------------------------------------+------------------------------------------------------------------------------------------------+
//|  Основные правила INI-текста.                                                                                                                                                        |
//|   1.   ОБЩИЕ ПОЛОЖЕНИЯ.                                                                                                                                                              |
//|   1.1.  Первая строка текста может быть заголовком. Можно записать туда что-нибудь полезное с обязательным комментарием ("//").                                                      |
//|   1.2.  Последний символ текста должен быть комбинацией знаков перевода каретки и переноса строки ("\r\n").                                                                          |
//|   1.3.  Пара ключ-значение всегда начинается с новой строки.                                                                                                                         |
//|   1.4.  Между ключом и его значением должен стоять символ равно ("=").                                                                                                               |
//|   1.5.  Ключи и их значения регистрозависимы.                                                                                                                                        |
//|   2.   КЛЮЧИ.                                                                                                                                                                        |
//|   2.1.  Ключи могут состоять из любых символов, кроме символов типографики, знаков пунктуации, математических знаков и зарезервированного слова "End".                               |
//|   3.   ЗНАЧЕНИЯ КЛЮЧЕЙ.                                                                                                                                                              |
//|   3.1.  Значение ключа может состоять только из букв латинского алфавита, букв русского алфавита, цифр, знаков пунктуации и разделителей слов (пробел (" ")).                        |
//|   3.2.  Значение ключа может быть равным пустой строке.                                                                                                                              |
//|   3.3.  Если применяется метод, возврщающий число, к пустой строке, то он возвращает ноль.                                                                                           |
//|   3.4.  Значения ключа могут перечисляться через вертикальную черту ("|"), точку с запятой (";") и запятую (",").                                                                    |
//|         Это означает набор значений (массив значений) для первого, второго и третьего измерений массива соответственно.                                                              |
//|          Последние символы (","), (";"), ("|") ставить не обязательно.                                                                                                               |
//|          Пример записывает одномерный массив: Param=1,2,3,4,5,6,7,8,9                                                                                                                |
//|          Пример записывает двухмерный массив: Param=1,2,3;4,5,6;7,8,9                                                                                                                |
//|          Пример записи трёхмерного массива: Param=1,2,3;4,5,6;7,8,9|1,2,3;4,5,6;7,8,9|1,2,3;4,5,6;7,8,9                                                                              |
//|   3.5.  Число может иметь первым символом знак плюс ("+") или минус ("-").                                                                                                           |
//|   3.6.  Значение ключа всегда заканчивается комбинацией знаков перевода каретки и переноса строки ("\r\n").                                                                          |
//|   4.   КОММЕНТАРИИ.                                                                                                                                                                  |
//|   4.1.  Возможны комментарии типа ("//") и ("/**/").                                                                                                                                 |
//|   4.2.  Комментарии синтаксическим анализом игнорируются.                                                                                                                            |
//|   5.   РАЗДЕЛЫ.                                                                                                                                                                      |
//|   5.1.  Имя раздела может состоять из любых символов, кроме текущих символов открывающего и закрывающего тегов раздела.                                                              |
//|   5.2.  Имя раздела ограничивается двумя любыми символами.                                                                                                                           |
//|   5.3.  Парсер может работать с любым количеством обозначений разделов.                                                                                                              |
//|   5.4.  При инициализации класса перечисление тегов разделов выглядит, как строка, где в каждой паре ячеек указывается открывающий и закрывающий имя раздела теги. Пример: "# []".   |
//|         Если закрывающий тег является пустой строкой, то необходимо вместо него указать пробел. Открывающий тег не может быть пробелом.                                              |
//|   5.5.  Возможны два варианта обозначения раздела по умолчанию.                                                                                                                      |
//|          Вариант 1. Блок раздела начинается с новой строки с символа ("#") и продолжается уникальным пользовательским именем и завершается пустой строкой (""). Пример: #UserSpace0. |
//|          Вариант 2. Блок раздела начинается с новой строки с символа ("["), продолжается уникальным пользовательским именем и завершается символом ("]"). Пример: [UserSpace0].      |
//|   5.6.  Парсер выбирает первое встретившееся из перечисленных обозначений разделов. Другие игнорирует и комментирует.                                                                |
//|   5.7.  Завершается блок раздела началом следующего блока другого раздела или тегом ("#End") для первого варианта и ("[End]") для второго варианта.                                  |
//|   5.8.  Если был установлен раздел, то перед применением любого метода чтения или установки пары ключ-значение необходимо вызвать метод установки или чтения раздела.                |
//|   5.9.  Нельзя использовать для имени раздела зарезервированное слово "End".                                                                                                         |
//|   6.   ПАРСЕР.                                                                                                                                                                       |
//|   6.1.  Все одинокие знаки перевода каретки ("\r") и знаки переноса строки ("\n") дополняются до комбинации --> ("\r\n").                                                            |
//|   6.2.  После комментариев типа ("/**/") и до комбинации знаков перевода каретки и переноса строки ("\r\n") все символы переносятся на новую строку.                                 |
//|   6.3.  Пробелы и знаки табуляции удаляются только из строк с парами ключ-значение.                                                                                                  |
//|   6.4.  Пробелы и знаки табуляции удаляются из значения ключа только спереди от знака равно ("=") и сзади значения до комбинации ("\r\n").                                           |
//|   6.5.  Повторные записи уже существующих ключей внутри одного раздела парсером автоматически комментируются ("//").                                                                 |
//|   6.6.  Повторные записи уже существующих разделов парсером автоматически комментируются ("//").                                                                                     |
//+--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+
#ifndef EXPFUNC
 #define EXPFUNC(type)   __declspec(dllexport) type __stdcall
#endif
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 1. ФУНКЦИИ УПРАВЛЕНИЯ INI-ФАЙЛОМ.
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 1.1. Функция закрывает INI-файл.
EXPFUNC(VOID) ParserClose();
//==============================================================================================================================================================================================================================================================
// 1.2. Функция удаляет INI-файл.
EXPFUNC(VOID) ParserDelete();
//==============================================================================================================================================================================================================================================================
// 1.3.1. Функция открывает INI-файл для записи или чтения, читает текст из файла в память, проверяет текст на ошибки, корректирует его, удаляя лишние пробелы, комментируя неправильные пары ключ-значение.
//        Начало работы с INI-файлом должна начинаться с функции "Open()". Завершаться работа должна функцией "Close()". Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserOpenA(LPCSTR     szFileName,   // Полный абсолютный путь к INI-файлу. Если путь указан относительный, то открывается файл с относительным путём: "...\MetaTrader 4\experts\files\MyFolder\MyFile.ini".
                                                   // В случае указанного относительного пути слеш спереди пути ставить не обязательно.
                          LPCSTR     szSectionTag, // Теги обозначения раздела. Строка, где указывается открывающий и закрывающий имя раздела теги. Пример: "# " или "[]".
                                                   // Если закрывающий тег является пустой строкой, то необходимо вместо него указать пробел. Открывающий тег не может быть пробелом.
                          const BOOL bUnicode);    // Флаг установки желаемой кодировки текста (ANSI/UNICODE) при записи нового файла. Флаг применяется если файл пуст или ещё не существует.
                                                   // При этом в начало файла записывается маркер порядка байтов UTF-16LE (FF FE).
                                                   // Если файл существует и отсутствует маркер порядка байтов, то при bUnicode=true применяется порядок байтов UTF-16LE.
                                                   // Если маркер порядка байтов существует в файле, то он анализируется на возможность обработки такого текста. Поддерживается только UTF-16LE, иначе вырабатывается исключение.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 1.3.2. Функция открывает INI-файл для записи или чтения, читает текст из файла в память, проверяет текст на ошибки, корректирует его, удаляя лишние пробелы, комментируя неправильные пары ключ-значение.
//        Начало работы с INI-файлом должна начинаться с функции "Open()". Завершаться работа должна функцией "Close()". Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserOpenW(LPCWSTR    szFileName,   // Полный абсолютный путь к INI-файлу. Если путь указан относительный, то открывается файл с относительным путём: "...\MetaTrader 4\experts\files\MyFolder\MyFile.ini".
                                                   // В случае указанного относительного пути слеш спереди пути ставить не обязательно.
                          LPCWSTR    szSectionTag, // Теги обозначения раздела. Строка, где указывается открывающий и закрывающий имя раздела теги. Пример: "# " или "[]".
                                                   // Если закрывающий тег является пустой строкой, то необходимо вместо него указать пробел. Открывающий тег не может быть пробелом.
                          const BOOL bUnicode);    // Флаг установки желаемой кодировки текста (ANSI/UNICODE) при записи нового файла. Флаг применяется если файл пуст или ещё не существует.
                                                   // При этом в начало файла записывается маркер порядка байтов UTF-16LE (FF FE).
                                                   // Если файл существует и отсутствует маркер порядка байтов, то при bUnicode=true применяется порядок байтов UTF-16LE.
                                                   // Если маркер порядка байтов существует в файле, то он анализируется на возможность обработки такого текста. Поддерживается только UTF-16LE, иначе вырабатывается исключение.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 1.3.3. Функция открывает INI-файл для записи или чтения, читает текст из файла в память, проверяет текст на ошибки, корректирует его, удаляя лишние пробелы, комментируя неправильные пары ключ-значение.
//        Начало работы с INI-файлом должна начинаться с функции "Open()". Завершаться работа должна функцией "Close()". Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserOpen  ParserOpenW
#else
 #define ParserOpen  ParserOpenA
#endif
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 2. СВОЙСТВА.
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 2.1.1. Функция возвращает TRUE, если ключ есть, иначе - FALSE. Функция работает с ANSI-строками.
EXPFUNC(BOOL) ParserIsKeyA(LPCSTR szName); // Имя ключа. Имя ключа может содержать имя раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.1.2. Функция возвращает TRUE, если ключ есть, иначе - FALSE. Функция работает с UNICODE-строками.
EXPFUNC(BOOL) ParserIsKeyW(LPCWSTR szName); // Имя ключа. Имя ключа может содержать имя раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.1.3. Функция возвращает TRUE, если ключ есть, иначе - FALSE. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserIsKey  ParserIsKeyW
#else
 #define ParserIsKey  ParserIsKeyA
#endif
//==============================================================================================================================================================================================================================================================
// 2.2.1. Функция возвращает TRUE, если раздел есть, иначе - FALSE. Функция работает с ANSI-строками.
EXPFUNC(BOOL) ParserIsSectionA(LPCSTR szName); // Имя раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.2.2. Функция возвращает TRUE, если раздел есть, иначе - FALSE. Функция работает с UNICODE-строками.
EXPFUNC(BOOL) ParserIsSectionW(LPCWSTR szName); // Имя раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.2.3. Функция возвращает TRUE, если раздел есть, иначе - FALSE. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserIsSection  ParserIsSectionW
#else
 #define ParserIsSection  ParserIsSectionA
#endif
//==============================================================================================================================================================================================================================================================
// 2.3.1. Функция возвращает количество пар ключ-значение в INI-файле по имени или префиксу. Функция работает с ANSI-строками.
EXPFUNC(INT) ParserKeysA(LPCSTR szName); // Имя ключа или его часть. Имя ключа может содержать имя раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.3.2. Функция возвращает количество пар ключ-значение в INI-файле по имени или префиксу. Функция работает с UNICODE-строками.
EXPFUNC(INT) ParserKeysW(LPCWSTR szName); // Имя ключа или его часть. Имя ключа может содержать имя раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.3.3. Функция возвращает количество пар ключ-значение в INI-файле по имени или префиксу. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserKeys  ParserKeysW
#else
 #define ParserKeys  ParserKeysA
#endif
//==============================================================================================================================================================================================================================================================
// 2.4.1. Функция возвращает имя раздела по его индексу. Если разделов нет, то функция возвращает пустую строку. Функция работает с ANSI-строками.
EXPFUNC(LPSTR) ParserSectionByIndexA(const SIZE_T stIndex); // Индекс раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.4.2. Функция возвращает имя раздела по его индексу. Если разделов нет, то функция возвращает пустую строку. Функция работает с UNICODE-строками.
EXPFUNC(LPWSTR) ParserSectionByIndexW(const SIZE_T stIndex); // Индекс раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.4.3. Функция возвращает имя раздела по его индексу. Если разделов нет, то функция возвращает пустую строку. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSectionByIndex  ParserSectionByIndexW
#else
 #define ParserSectionByIndex  ParserSectionByIndexA
#endif
//==============================================================================================================================================================================================================================================================
// 2.5.1. Функция возвращает количество разделов в INI-файле по имени или префиксу. Функция работает с ANSI-строками.
EXPFUNC(INT) ParserSectionsA(LPCSTR szName); // Имя раздела или префикс. При пустой строке возвращается количество всех разделов.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.5.2. Функция возвращает количество разделов в INI-файле по имени или префиксу. Функция работает с UNICODE-строками.
EXPFUNC(INT) ParserSectionsW(LPCWSTR szName); // Имя раздела или префикс. При пустой строке возвращается количество всех разделов.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 2.5.3. Функция возвращает количество разделов в INI-файле по имени или префиксу. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSections  ParserSectionsW
#else
 #define ParserSections  ParserSectionsA
#endif
//==============================================================================================================================================================================================================================================================
// 2.6. Функция возвращает размер INI-файла в байтах.
EXPFUNC(INT) ParserSize();
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 3. ПАРСЕР.
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 3.1. Функция очищает буфер текста в парсере.
EXPFUNC(VOID) ParserClearText();
//==============================================================================================================================================================================================================================================================
// 3.2. Функция производит синтактический анализ и правку текста. При автоматической записи INI-файла проводить синтаксический анализ не требуется. При ручном заполнении INI-файл рекомендуется проверить на ошибки.
EXPFUNC(VOID) ParserMake();
//==============================================================================================================================================================================================================================================================
// 3.3.1. Функция возвращает прочтённый из INI-файла или формируемый текст. Функция работает с ANSI-строками.
EXPFUNC(LPSTR) ParserTextA();
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 3.3.2. Функция возвращает прочтённый из INI-файла или формируемый текст. Функция работает с UNICODE-строками.
EXPFUNC(LPWSTR) ParserTextW();
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 3.3.3. Функция возвращает прочтённый из INI-файла или формируемый текст. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserText  ParserTextW
#else
 #define ParserText  ParserTextA
#endif
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 4. ФУНКЦИИ УСТАНОВКИ РАЗДЕЛА.
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 4.1. Функция закрывает раздел при записи или инициализирует пустой строкой имя раздела при чтении или перезаписи.
EXPFUNC(VOID) ParserSectionClose();
//==============================================================================================================================================================================================================================================================
// 4.2.1. Функция открывает раздел. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSectionOpenA(LPCSTR szSection); // Имя раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 4.2.2. Функция открывает раздел. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSectionOpenW(LPCWSTR szSection); // Имя раздела.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 4.2.3. Функция открывает раздел. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSectionOpen  ParserSectionOpenW
#else
 #define ParserSectionOpen  ParserSectionOpenA
#endif
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 5. ФУНКЦИИ ЗАПИСИ.
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 5.1.1. Функция записывает комментарий. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetCommentA(LPCSTR szComment); // Строка с комментарием.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.1.2. Функция записывает комментарий. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetCommentW(LPCWSTR szComment); // Строка с комментарием.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.1.3. Функция записывает комментарий. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetComment  ParserSetCommentW
#else
 #define ParserSetComment  ParserSetCommentA
#endif
//==============================================================================================================================================================================================================================================================
// 5.2.1. Функция записывает заголовок INI-файла. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetTitleA(LPCSTR szTitle); // Строка с заголовком.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.2.2. Функция записывает заголовок INI-файла. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetTitleW(LPCWSTR szTitle); // Строка с заголовком.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.2.3. Функция записывает заголовок INI-файла. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetTitle  ParserSetTitleW
#else
 #define ParserSetTitle  ParserSetTitleA
#endif
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 5.3. Функции записи чисел и строк.
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 5.3.1.1. Функция записывает числовое значения ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyBoolA(LPCSTR     szKey,   // Ключ.
                                const bool bValue); // Числовое значение типа bool.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.1.2. Функция записывает числовое значения ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyBoolW(LPCWSTR    szKey,   // Ключ.
                                const bool bValue); // Числовое значение типа bool.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.1.3. Функция записывает числовое значения ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyBool  ParserSetKeyBoolW
#else
 #define ParserSetKeyBool  ParserSetKeyBoolA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.2.1. Функция записывает числовое значения ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyCharA(LPCSTR     szKey,   // Ключ.
                                const CHAR cValue); // Числовое значение типа CHAR.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.2.2. Функция записывает числовое значения ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyCharW(LPCWSTR    szKey,   // Ключ.
                                const CHAR cValue); // Числовое значение типа CHAR.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.2.3. Функция записывает числовое значения ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyChar  ParserSetKeyCharW
#else
 #define ParserSetKeyChar  ParserSetKeyCharA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.3.1. Функция записывает числовое значения ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUCharA(LPCSTR      szKey,    // Ключ.
                                 const UCHAR ucValue); // Числовое значение типа UCHAR.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.3.2. Функция записывает числовое значения ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUCharW(LPCWSTR     szKey,    // Ключ.
                                 const UCHAR ucValue); // Числовое значение типа UCHAR.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.3.3. Функция записывает числовое значения ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUChar  ParserSetKeyUCharW
#else
 #define ParserSetKeyUChar  ParserSetKeyUCharA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.4.1. Функция записывает числовое значения ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyShortA(LPCSTR      szKey,    // Ключ.
                                 const SHORT shValue); // Числовое значение типа SHORT.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.4.2. Функция записывает числовое значения ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyShortW(LPCWSTR     szKey,    // Ключ.
                                 const SHORT shValue); // Числовое значение типа SHORT.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.4.3. Функция записывает числовое значения ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyShort  ParserSetKeyShortW
#else
 #define ParserSetKeyShort  ParserSetKeyShortA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.5.1. Функция записывает числовое значения ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUShortA(LPCSTR       szKey,     // Ключ.
                                  const USHORT ushValue); // Числовое значение типа USHORT.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.5.2. Функция записывает числовое значения ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUShortW(LPCWSTR      szKey,     // Ключ.
                                  const USHORT ushValue); // Числовое значение типа USHORT.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.5.3. Функция записывает числовое значения ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUShort  ParserSetKeyUShortW
#else
 #define ParserSetKeyUShort  ParserSetKeyUShortA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.6.1. Функция записывает числовое значения ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyIntA(LPCSTR    szKey,   // Ключ.
                               const INT nValue); // Числовое значение типа INT.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.6.2. Функция записывает числовое значения ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyIntW(LPCWSTR   szKey,   // Ключ.
                               const INT nValue); // Числовое значение типа INT.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.6.3. Функция записывает числовое значения ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyInt  ParserSetKeyIntW
#else
 #define ParserSetKeyInt  ParserSetKeyIntA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.7.1. Функция записывает числовое значения ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUIntA(LPCSTR     szKey,    // Ключ.
                                const UINT uiValue); // Числовое значение типа UINT.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.7.2. Функция записывает числовое значения ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUIntW(LPCWSTR    szKey,    // Ключ.
                                const UINT uiValue); // Числовое значение типа UINT.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.7.3. Функция записывает числовое значения ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUInt  ParserSetKeyUIntW
#else
 #define ParserSetKeyUInt  ParserSetKeyUIntA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.8.1. Функция записывает числовое значения ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyLong64A(LPCSTR       szKey,     // Ключ.
                                  const LONG64 l64Value); // Числовое значение типа LONG64.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.8.2. Функция записывает числовое значения ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyLong64W(LPCWSTR      szKey,     // Ключ.
                                  const LONG64 l64Value); // Числовое значение типа LONG64.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.8.3. Функция записывает числовое значения ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyLong64  ParserSetKeyLong64W
#else
 #define ParserSetKeyLong64  ParserSetKeyLong64A
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.9.1. Функция записывает числовое значения ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyULong64A(LPCSTR        szKey,      // Ключ.
                                   const ULONG64 ul64Value); // Числовое значение типа ULONG64.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.9.2. Функция записывает числовое значения ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyULong64W(LPCWSTR       szKey,      // Ключ.
                                   const ULONG64 ul64Value); // Числовое значение типа ULONG64.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.9.3. Функция записывает числовое значения ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define Parser  ParserSetKeyULong64W
#else
 #define Parser  ParserSetKeyULong64A
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.10.1. Функция записывает числовое значения ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyFloatA(LPCSTR      szKey,      // Ключ.
                                 const FLOAT fValue,     // Числовое значение типа FLOAT.
                                 const WORD  wDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.10.2. Функция записывает числовое значения ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyFloatW(LPCWSTR     szKey,      // Ключ.
                                 const FLOAT fValue,     // Числовое значение типа FLOAT.
                                 const WORD  wDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.10.3. Функция записывает числовое значения ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyFloat  ParserSetKeyFloatW
#else
 #define ParserSetKeyFloat  ParserSetKeyFloatA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.11.1. Функция записывает числовое значения ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyDoubleA(LPCSTR       szKey,      // Ключ.
                                  const DOUBLE dValue,     // Числовое значение типа DOUBLE.
                                  const INT    nDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.11.2. Функция записывает числовое значения ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyDoubleW(LPCWSTR      szKey,      // Ключ.
                                  const DOUBLE dValue,     // Числовое значение типа DOUBLE.
                                  const INT    nDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.11.3. Функция записывает числовое значения ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyDouble  ParserSetKeyDoubleW
#else
 #define ParserSetKeyDouble  ParserSetKeyDoubleA
#endif
//==============================================================================================================================================================================================================================================================
// 5.3.12.1. Функция записывает строковое значения ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyStringA(LPCSTR szKey,    // Ключ.
                                  LPCSTR szValue); // Строковое значение.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.12.2. Функция записывает строковое значения ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyStringW(LPCWSTR szKey,    // Ключ.
                                  LPCWSTR szValue); // Строковое значение.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.3.12.3. Функция записывает строковое значения ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyString  ParserSetKeyStringW
#else
 #define ParserSetKeyString  ParserSetKeyStringA
#endif
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 5.4. Функции записи одномерных массивов.
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 5.4.1.1. Функция записывает одномерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyBoolArrayA(LPCSTR       szKey,   // Ключ.
                                     const pbool  abArray, // Указатель на статический одномерный массив логических значений типа bool.
                                     const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.1.2. Функция записывает одномерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyBoolArrayW(LPCWSTR      szKey,   // Ключ.
                                     const pbool  abArray, // Указатель на статический одномерный массив логических значений типа bool.
                                     const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.1.3. Функция записывает одномерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyBoolArray  ParserSetKeyBoolArrayW
#else
 #define ParserSetKeyBoolArray  ParserSetKeyBoolArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.2.1. Функция записывает одномерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyCharArrayA(LPCSTR       szKey,   // Ключ.
                                     const PCHAR  acArray, // Указатель на статический одномерный массив числовых значений типа CHAR.
                                     const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.2.2. Функция записывает одномерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyCharArrayW(LPCWSTR      szKey,   // Ключ.
                                     const PCHAR  acArray, // Указатель на статический одномерный массив числовых значений типа CHAR.
                                     const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.2.3. Функция записывает одномерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyCharArray  ParserSetKeyCharArrayW
#else
 #define ParserSetKeyCharArray  ParserSetKeyCharArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.3.1. Функция записывает одномерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUCharArrayA(LPCSTR       szKey,    // Ключ.
                                      const PUCHAR aucArray, // Указатель на статический одномерный массив числовых значений типа UCHAR.
                                      const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.3.2. Функция записывает одномерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUCharArrayW(LPCWSTR      szKey,    // Ключ.
                                      const PUCHAR aucArray, // Указатель на статический одномерный массив числовых значений типа UCHAR.
                                      const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.3.3. Функция записывает одномерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUCharArray  ParserSetKeyUCharArrayW
#else
 #define ParserSetKeyUCharArray  ParserSetKeyUCharArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.4.1. Функция записывает одномерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyShortArrayA(LPCSTR       szKey,    // Ключ.
                                      const PSHORT ashArray, // Указатель на статический одномерный массив числовых значений типа SHORT.
                                      const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.4.2. Функция записывает одномерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyShortArrayW(LPCWSTR      szKey,    // Ключ.
                                      const PSHORT ashArray, // Указатель на статический одномерный массив числовых значений типа SHORT.
                                      const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.4.3. Функция записывает одномерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyShortArray  ParserSetKeyShortArrayW
#else
 #define ParserSetKeyShortArray  ParserSetKeyShortArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.5.1. Функция записывает одномерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUShortArrayA(LPCSTR        szKey,     // Ключ.
                                       const PUSHORT aushArray, // Указатель на статический одномерный массив числовых значений типа USHORT.
                                       const SIZE_T  stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.5.2. Функция записывает одномерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUShortArrayW(LPCWSTR       szKey,     // Ключ.
                                       const PUSHORT aushArray, // Указатель на статический одномерный массив числовых значений типа USHORT.
                                       const SIZE_T  stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.5.3. Функция записывает одномерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUShortArray  ParserSetKeyUShortArrayW
#else
 #define ParserSetKeyUShortArray  ParserSetKeyUShortArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.6.1. Функция записывает одномерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyIntArrayA(LPCSTR       szKey,   // Ключ.
                                    const PINT   anArray, // Указатель на статический одномерный массив числовых значений типа INT.
                                    const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.6.2. Функция записывает одномерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyIntArrayW(LPCWSTR      szKey,   // Ключ.
                                    const PINT   anArray, // Указатель на статический одномерный массив числовых значений типа INT.
                                    const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.6.3. Функция записывает одномерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyIntArray  ParserSetKeyIntArrayW
#else
 #define ParserSetKeyIntArray  ParserSetKeyIntArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.7.1. Функция записывает одномерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUIntArrayA(LPCSTR       szKey,    // Ключ.
                                     const PUINT  auiArray, // Указатель на статический одномерный массив числовых значений типа UINT.
                                     const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.7.2. Функция записывает одномерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUIntArrayW(LPCWSTR      szKey,    // Ключ.
                                     const PUINT  auiArray, // Указатель на статический одномерный массив числовых значений типа UINT.
                                     const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.7.3. Функция записывает одномерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUIntArray  ParserSetKeyUIntArrayW
#else
 #define ParserSetKeyUIntArray  ParserSetKeyUIntArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.8.1. Функция записывает одномерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyLong64ArrayA(LPCSTR        szKey,     // Ключ.
                                       const PLONG64 al64Array, // Указатель на статический одномерный массив числовых значений типа LONG64.
                                       const SIZE_T  stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.8.2. Функция записывает одномерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyLong64ArrayW(LPCWSTR       szKey,     // Ключ.
                                       const PLONG64 al64Array, // Указатель на статический одномерный массив числовых значений типа LONG64.
                                       const SIZE_T  stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.8.3. Функция записывает одномерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyLong64Array  ParserSetKeyLong64ArrayW
#else
 #define ParserSetKeyLong64Array  ParserSetKeyLong64ArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.9.1. Функция записывает одномерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyULong64ArrayA(LPCSTR         szKey,      // Ключ.
                                        const PULONG64 aul64Array, // Указатель на статический одномерный массив числовых значений типа ULONG64.
                                        const SIZE_T   stSize);    // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.9.2. Функция записывает одномерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyULong64ArrayW(LPCWSTR        szKey,      // Ключ.
                                        const PULONG64 aul64Array, // Указатель на статический одномерный массив числовых значений типа ULONG64.
                                        const SIZE_T   stSize);    // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.9.3. Функция записывает одномерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyULong64Array  ParserSetKeyULong64ArrayW
#else
 #define ParserSetKeyULong64Array  ParserSetKeyULong64ArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.10.1. Функция записывает одномерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyFloatArrayA(LPCSTR       szKey,      // Ключ.
                                      const PFLOAT afArray,    // Указатель на статический одномерный массив числовых значений типа FLOAT.
                                      const SIZE_T stSize,     // Размер массива.
                                      const WORD   wDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.10.2. Функция записывает одномерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyFloatArrayW(LPCWSTR      szKey,      // Ключ.
                                      const PFLOAT afArray,    // Указатель на статический одномерный массив числовых значений типа FLOAT.
                                      const SIZE_T stSize,     // Размер массива.
                                      const WORD   wDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.10.3. Функция записывает одномерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyFloatArray  ParserSetKeyFloatArrayW
#else
 #define ParserSetKeyFloatArray  ParserSetKeyFloatArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.11.1. Функция записывает одномерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyDoubleArrayA(LPCSTR        szKey,      // Ключ.
                                       const PDOUBLE adArray,    // Указатель на статический одномерный массив числовых значений типа DOUBLE.
                                       const SIZE_T  stSize,     // Размер массива.
                                       const INT     nDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.11.2. Функция записывает одномерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyDoubleArrayW(LPCWSTR       szKey,      // Ключ.
                                       const PDOUBLE adArray,    // Указатель на статический одномерный массив числовых значений типа DOUBLE.
                                       const SIZE_T  stSize,     // Размер массива.
                                       const INT     nDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.11.3. Функция записывает одномерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyDoubleArray  ParserSetKeyDoubleArrayW
#else
 #define ParserSetKeyDoubleArray  ParserSetKeyDoubleArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.12.1. Функция записывает одномерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyStringArrayA(LPCSTR       szKey,     // Ключ.
                                       LPCSTR*      aszString, // Указатель на статический одномерный массив указателей на с-строки.
                                       const SIZE_T stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.12.2. Функция записывает одномерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyStringArrayW(LPCWSTR      szKey,     // Ключ.
                                       LPCWSTR*     aszString, // Указатель на статический одномерный массив указателей на с-строки.
                                       const SIZE_T stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.12.3. Функция записывает одномерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyStringArray  ParserSetKeyStringArrayW
#else
 #define ParserSetKeyStringArray  ParserSetKeyStringArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 5.4.13.1. Функция записывает одномерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyStringArrayMA(LPCSTR             szKey,    // Ключ.
                                        const MT::PMQLSTRA aSMqlStr, // Указатель на статический одномерный массив указателей на MQL-строки.
                                        const SIZE_T       stSize);  // Размер первого измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.13.2. Функция записывает одномерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyStringArrayMW(LPCWSTR            szKey,    // Ключ.
                                        const MT::PMQLSTRW aSMqlStr, // Указатель на статический одномерный массив указателей на MQL-строки.
                                        const SIZE_T       stSize);  // Размер первого измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.4.13.3. Функция записывает одномерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyStringArrayM  ParserSetKeyStringArrayMW
#else
 #define ParserSetKeyStringArrayM  ParserSetKeyStringArrayMA
#endif
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 5.5. Функции записи двухмерных массивов.
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 5.5.1.1. Функция записывает двухмерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyBoolArray2A(LPCSTR       szKey,    // Ключ.
                                      const pbool  a2bArray, // Указатель на статический двухмерный массив логических значений типа bool.
                                      const SIZE_T stSize1,  // Размер первого измерения массива.
                                      const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.1.2. Функция записывает двухмерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyBoolArray2W(LPCWSTR      szKey,    // Ключ.
                                      const pbool  a2bArray, // Указатель на статический двухмерный массив логических значений типа bool.
                                      const SIZE_T stSize1,  // Размер первого измерения массива.
                                      const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.1.3. Функция записывает двухмерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyBoolArray2  ParserSetKeyBoolArray2W
#else
 #define ParserSetKeyBoolArray2  ParserSetKeyBoolArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.2.1. Функция записывает двухмерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyCharArray2A(LPCSTR       szKey,    // Ключ.
                                      const PCHAR  a2cArray, // Указатель на статический двухмерный массив числовых значений типа CHAR.
                                      const SIZE_T stSize1,  // Размер первого измерения массива.
                                      const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.2.2. Функция записывает двухмерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyCharArray2W(LPCWSTR      szKey,    // Ключ.
                                      const PCHAR  a2cArray, // Указатель на статический двухмерный массив числовых значений типа CHAR.
                                      const SIZE_T stSize1,  // Размер первого измерения массива.
                                      const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.2.3. Функция записывает двухмерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyCharArray2  ParserSetKeyCharArray2W
#else
 #define ParserSetKeyCharArray2  ParserSetKeyCharArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.3.1. Функция записывает двухмерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUCharArray2A(LPCSTR       szKey,     // Ключ.
                                       const PUCHAR a2ucArray, // Указатель на статический двухмерный массив числовых значений типа UCHAR.
                                       const SIZE_T stSize1,   // Размер первого измерения массива.
                                       const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.3.2. Функция записывает двухмерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUCharArray2W(LPCWSTR      szKey,     // Ключ.
                                       const PUCHAR a2ucArray, // Указатель на статический двухмерный массив числовых значений типа UCHAR.
                                       const SIZE_T stSize1,   // Размер первого измерения массива.
                                       const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.3.3. Функция записывает двухмерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUCharArray2  ParserSetKeyUCharArray2W
#else
 #define ParserSetKeyUCharArray2  ParserSetKeyUCharArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.4.1. Функция записывает двухмерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyShortArray2A(LPCSTR       szKey,     // Ключ.
                                       const PSHORT a2shArray, // Указатель на статический двухмерный массив числовых значений типа SHORT.
                                       const SIZE_T stSize1,   // Размер первого измерения массива.
                                       const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.4.2. Функция записывает двухмерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyShortArray2W(LPCWSTR      szKey,     // Ключ.
                                       const PSHORT a2shArray, // Указатель на статический двухмерный массив числовых значений типа SHORT.
                                       const SIZE_T stSize1,   // Размер первого измерения массива.
                                       const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.4.3. Функция записывает двухмерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyShortArray2  ParserSetKeyShortArray2W
#else
 #define ParserSetKeyShortArray2  ParserSetKeyShortArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.5.1. Функция записывает двухмерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUShortArray2A(LPCSTR        szKey,      // Ключ.
                                        const PUSHORT a2ushArray, // Указатель на статический двухмерный массив числовых значений типа USHORT.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.5.2. Функция записывает двухмерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUShortArray2W(LPCWSTR       szKey,      // Ключ.
                                        const PUSHORT a2ushArray, // Указатель на статический двухмерный массив числовых значений типа USHORT.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.5.3. Функция записывает двухмерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUShortArray2  ParserSetKeyUShortArray2W
#else
 #define ParserSetKeyUShortArray2  ParserSetKeyUShortArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.6.1. Функция записывает двухмерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyIntArray2A(LPCSTR       szKey,    // Ключ.
                                     const PINT  a2nArray, // Указатель на статический двухмерный массив числовых значений типа INT.
                                     const SIZE_T stSize1,  // Размер первого измерения массива.
                                     const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.6.2. Функция записывает двухмерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyIntArray2W(LPCWSTR      szKey,    // Ключ.
                                     const PINT  a2nArray, // Указатель на статический двухмерный массив числовых значений типа INT.
                                     const SIZE_T stSize1,  // Размер первого измерения массива.
                                     const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.6.3. Функция записывает двухмерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyIntArray2  ParserSetKeyIntArray2W
#else
 #define ParserSetKeyIntArray2  ParserSetKeyIntArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.7.1. Функция записывает двухмерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUIntArray2A(LPCSTR       szKey,     // Ключ.
                                      const PUINT  a2uiArray, // Указатель на статический двухмерный массив числовых значений типа UINT.
                                      const SIZE_T stSize1,   // Размер первого измерения массива.
                                      const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.7.2. Функция записывает двухмерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUIntArray2W(LPCWSTR      szKey,     // Ключ.
                                      const PUINT  a2uiArray, // Указатель на статический двухмерный массив числовых значений типа UINT.
                                      const SIZE_T stSize1,   // Размер первого измерения массива.
                                      const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.7.3. Функция записывает двухмерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUIntArray2  ParserSetKeyUIntArray2W
#else
 #define ParserSetKeyUIntArray2  ParserSetKeyUIntArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.8.1. Функция записывает двухмерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyLong64Array2A(LPCSTR        szKey,      // Ключ.
                                        const PLONG64 a2l64Array, // Указатель на статический двухмерный массив числовых значений типа LONG64.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.8.2. Функция записывает двухмерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyLong64Array2W(LPCWSTR       szKey,      // Ключ.
                                        const PLONG64 a2l64Array, // Указатель на статический двухмерный массив числовых значений типа LONG64.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.8.3. Функция записывает двухмерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyLong64Array2  ParserSetKeyLong64Array2W
#else
 #define ParserSetKeyLong64Array2  ParserSetKeyLong64Array2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.9.1. Функция записывает двухмерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyULong64Array2A(LPCSTR         szKey,       // Ключ.
                                         const PULONG64 a2ul64Array, // Указатель на статический двухмерный массив числовых значений типа ULONG64.
                                         const SIZE_T   stSize1,     // Размер первого измерения массива.
                                         const SIZE_T   stSize2);    // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.9.2. Функция записывает двухмерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyULong64Array2W(LPCWSTR        szKey,       // Ключ.
                                         const PULONG64 a2ul64Array, // Указатель на статический двухмерный массив числовых значений типа ULONG64.
                                         const SIZE_T   stSize1,     // Размер первого измерения массива.
                                         const SIZE_T   stSize2);    // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.9.3. Функция записывает двухмерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyULong64Array2  ParserSetKeyULong64Array2W
#else
 #define ParserSetKeyULong64Array2  ParserSetKeyULong64Array2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.10.1. Функция записывает двухмерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyFloatArray2A(LPCSTR       szKey,      // Ключ.
                                       const PFLOAT a2fArray,   // Указатель на статический двухмерный массив числовых значений типа FLOAT.
                                       const SIZE_T stSize1,    // Размер первого измерения массива.
                                       const SIZE_T stSize2,    // Размер второго измерения массива.
                                       const WORD   wDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.10.2. Функция записывает двухмерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyFloatArray2W(LPCWSTR      szKey,      // Ключ.
                                       const PFLOAT a2fArray,   // Указатель на статический двухмерный массив числовых значений типа FLOAT.
                                       const SIZE_T stSize1,    // Размер первого измерения массива.
                                       const SIZE_T stSize2,    // Размер второго измерения массива.
                                       const WORD   wDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.10.3. Функция записывает двухмерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyFloatArray2  ParserSetKeyFloatArray2W
#else
 #define ParserSetKeyFloatArray2  ParserSetKeyFloatArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.11.1. Функция записывает двухмерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyDoubleArray2A(LPCSTR        szKey,      // Ключ.
                                        const PDOUBLE a2dArray,   // Указатель на статический двухмерный массив числовых значений типа DOUBLE.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2,    // Размер второго измерения массива.
                                        const INT     nDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.11.2. Функция записывает двухмерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyDoubleArray2W(LPCWSTR       szKey,      // Ключ.
                                        const PDOUBLE a2dArray,   // Указатель на статический двухмерный массив числовых значений типа DOUBLE.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2,    // Размер второго измерения массива.
                                        const INT     nDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.11.3. Функция записывает двухмерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyDoubleArray2  ParserSetKeyDoubleArray2W
#else
 #define ParserSetKeyDoubleArray2  ParserSetKeyDoubleArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.12.1. Функция записывает двухмерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyStringArray2A(LPCSTR       szKey,      // Ключ.
                                        LPCSTR*      a2szString, // Указатель на статический двухмерный массив указателей на с-строки.
                                        const SIZE_T stSize1,    // Размер первого измерения массива.
                                        const SIZE_T stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.12.2. Функция записывает двухмерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyStringArray2W(LPCWSTR      szKey,      // Ключ.
                                        LPCWSTR*     a2szString, // Указатель на статический двухмерный массив указателей на с-строки.
                                        const SIZE_T stSize1,    // Размер первого измерения массива.
                                        const SIZE_T stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.12.3. Функция записывает двухмерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyStringArray2  ParserSetKeyStringArray2W
#else
 #define ParserSetKeyStringArray2  ParserSetKeyStringArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 5.5.13.1. Функция записывает двухмерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyStringArray2MA(LPCSTR             szKey,     // Ключ.
                                         const MT::PMQLSTRA a2SMqlStr, // Указатель на статический двухмерный массив указателей на MQL-строки.
                                         const SIZE_T       stSize1,   // Размер первого измерения массива.
                                         const SIZE_T       stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.13.2. Функция записывает двухмерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyStringArray2MW(LPCWSTR            szKey,     // Ключ.
                                         const MT::PMQLSTRW a2SMqlStr, // Указатель на статический двухмерный массив указателей на MQL-строки.
                                         const SIZE_T       stSize1,   // Размер первого измерения массива.
                                         const SIZE_T       stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.5.13.3. Функция записывает двухмерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyStringArray2M  ParserSetKeyStringArray2MW
#else
 #define ParserSetKeyStringArray2M  ParserSetKeyStringArray2MA
#endif
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 5.6. Функции записи трёхмерных массивов.
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 5.6.1.1. Функция записывает трёхмерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyBoolArray3A(LPCSTR       szKey,    // Ключ.
                                      const pbool  a3bArray, // Указатель на статический трёхмерный массив логических значений типа bool.
                                      const SIZE_T stSize1,  // Размер первого измерения массива.
                                      const SIZE_T stSize2,  // Размер второго измерения массива.
                                      const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.1.2. Функция записывает трёхмерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyBoolArray3W(LPCWSTR      szKey,    // Ключ.
                                      const pbool  a3bArray, // Указатель на статический трёхмерный массив логических значений типа bool.
                                      const SIZE_T stSize1,  // Размер первого измерения массива.
                                      const SIZE_T stSize2,  // Размер второго измерения массива.
                                      const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.1.3. Функция записывает трёхмерный массив числовых значений ключа типа bool. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyBoolArray3  ParserSetKeyBoolArray3W
#else
 #define ParserSetKeyBoolArray3  ParserSetKeyBoolArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.2.1. Функция записывает трёхмерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyCharArray3A(LPCSTR       szKey,    // Ключ.
                                      const PCHAR  a3cArray, // Указатель на статический трёхмерный массив числовых значений типа CHAR.
                                      const SIZE_T stSize1,  // Размер первого измерения массива.
                                      const SIZE_T stSize2,  // Размер второго измерения массива.
                                      const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.2.2. Функция записывает трёхмерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyCharArray3W(LPCWSTR      szKey,    // Ключ.
                                      const PCHAR  a3cArray, // Указатель на статический трёхмерный массив числовых значений типа CHAR.
                                      const SIZE_T stSize1,  // Размер первого измерения массива.
                                      const SIZE_T stSize2,  // Размер второго измерения массива.
                                      const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.2.3. Функция записывает трёхмерный массив числовых значений ключа типа CHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyCharArray3  ParserSetKeyCharArray3W
#else
 #define ParserSetKeyCharArray3  ParserSetKeyCharArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.3.1. Функция записывает трёхмерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUCharArray3A(LPCSTR       szKey,     // Ключ.
                                       const PUCHAR a3ucArray, // Указатель на статический трёхмерный массив числовых значений типа UCHAR.
                                       const SIZE_T stSize1,   // Размер первого измерения массива.
                                       const SIZE_T stSize2,   // Размер второго измерения массива.
                                       const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.3.2. Функция записывает трёхмерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUCharArray3W(LPCWSTR      szKey,     // Ключ.
                                       const PUCHAR a3ucArray, // Указатель на статический трёхмерный массив числовых значений типа UCHAR.
                                       const SIZE_T stSize1,   // Размер первого измерения массива.
                                       const SIZE_T stSize2,   // Размер второго измерения массива.
                                       const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.3.3. Функция записывает трёхмерный массив числовых значений ключа типа UCHAR. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUCharArray3  ParserSetKeyUCharArray3W
#else
 #define ParserSetKeyUCharArray3  ParserSetKeyUCharArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.4.1. Функция записывает трёхмерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyShortArray3A(LPCSTR       szKey,     // Ключ.
                                       const PSHORT a3shArray, // Указатель на статический трёхмерный массив числовых значений типа SHORT.
                                       const SIZE_T stSize1,   // Размер первого измерения массива.
                                       const SIZE_T stSize2,   // Размер второго измерения массива.
                                       const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.4.2. Функция записывает трёхмерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyShortArray3W(LPCWSTR      szKey,     // Ключ.
                                       const PSHORT a3shArray, // Указатель на статический трёхмерный массив числовых значений типа SHORT.
                                       const SIZE_T stSize1,   // Размер первого измерения массива.
                                       const SIZE_T stSize2,   // Размер второго измерения массива.
                                       const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.4.3. Функция записывает трёхмерный массив числовых значений ключа типа SHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyShortArray3  ParserSetKeyShortArray3W
#else
 #define ParserSetKeyShortArray3  ParserSetKeyShortArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.5.1. Функция записывает трёхмерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUShortArray3A(LPCSTR        szKey,      // Ключ.
                                        const PUSHORT a3ushArray, // Указатель на статический трёхмерный массив числовых значений типа USHORT.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2,    // Размер второго измерения массива.
                                        const SIZE_T  stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.5.2. Функция записывает трёхмерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUShortArray3W(LPCWSTR       szKey,      // Ключ.
                                        const PUSHORT a3ushArray, // Указатель на статический трёхмерный массив числовых значений типа USHORT.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2,    // Размер второго измерения массива.
                                        const SIZE_T  stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.5.3. Функция записывает трёхмерный массив числовых значений ключа типа USHORT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUShortArray3  ParserSetKeyUShortArray3W
#else
 #define ParserSetKeyUShortArray3  ParserSetKeyUShortArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.6.1. Функция записывает трёхмерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyIntArray3A(LPCSTR       szKey,    // Ключ.
                                     const PINT   a3nArray, // Указатель на статический трёхмерный массив числовых значений типа INT.
                                     const SIZE_T stSize1,  // Размер первого измерения массива.
                                     const SIZE_T stSize2,  // Размер второго измерения массива.
                                     const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.6.2. Функция записывает трёхмерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyIntArray3W(LPCWSTR      szKey,    // Ключ.
                                     const PINT   a3nArray, // Указатель на статический трёхмерный массив числовых значений типа INT.
                                     const SIZE_T stSize1,  // Размер первого измерения массива.
                                     const SIZE_T stSize2,  // Размер второго измерения массива.
                                     const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.6.3. Функция записывает трёхмерный массив числовых значений ключа типа INT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyIntArray3  ParserSetKeyIntArray3W
#else
 #define ParserSetKeyIntArray3  ParserSetKeyIntArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.7.1. Функция записывает трёхмерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyUIntArray3A(LPCSTR       szKey,     // Ключ.
                                      const PUINT  a3uiArray, // Указатель на статический трёхмерный массив числовых значений типа UINT.
                                      const SIZE_T stSize1,   // Размер первого измерения массива.
                                      const SIZE_T stSize2,   // Размер второго измерения массива.
                                      const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.7.2. Функция записывает трёхмерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyUIntArray3W(LPCWSTR      szKey,     // Ключ.
                                      const PUINT  a3uiArray, // Указатель на статический трёхмерный массив числовых значений типа UINT.
                                      const SIZE_T stSize1,   // Размер первого измерения массива.
                                      const SIZE_T stSize2,   // Размер второго измерения массива.
                                      const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.7.3. Функция записывает трёхмерный массив числовых значений ключа типа UINT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyUIntArray3  ParserSetKeyUIntArray3W
#else
 #define ParserSetKeyUIntArray3  ParserSetKeyUIntArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.8.1. Функция записывает трёхмерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyLong64Array3A(LPCSTR        szKey,      // Ключ.
                                        const PLONG64 a3l64Array, // Указатель на статический трёхмерный массив числовых значений типа LONG64.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2,    // Размер второго измерения массива.
                                        const SIZE_T  stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.8.2. Функция записывает трёхмерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyLong64Array3W(LPCWSTR       szKey,      // Ключ.
                                        const PLONG64 a3l64Array, // Указатель на статический трёхмерный массив числовых значений типа LONG64.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2,    // Размер второго измерения массива.
                                        const SIZE_T  stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.8.3. Функция записывает трёхмерный массив числовых значений ключа типа LONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyLong64Array3  ParserSetKeyLong64Array3W
#else
 #define ParserSetKeyLong64Array3  ParserSetKeyLong64Array3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.9.1. Функция записывает трёхмерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyULong64Array3A(LPCSTR         szKey,       // Ключ.
                                         const PULONG64 a3ul64Array, // Указатель на статический трёхмерный массив числовых значений типа ULONG64.
                                         const SIZE_T   stSize1,     // Размер первого измерения массива.
                                         const SIZE_T   stSize2,     // Размер второго измерения массива.
                                         const SIZE_T   stSize3);    // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.9.2. Функция записывает трёхмерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyULong64Array3W(LPCWSTR        szKey,       // Ключ.
                                         const PULONG64 a3ul64Array, // Указатель на статический трёхмерный массив числовых значений типа ULONG64.
                                         const SIZE_T   stSize1,     // Размер первого измерения массива.
                                         const SIZE_T   stSize2,     // Размер второго измерения массива.
                                         const SIZE_T   stSize3);    // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.9.3. Функция записывает трёхмерный массив числовых значений ключа типа ULONG64. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyULong64Array3  ParserSetKeyULong64Array3W
#else
 #define ParserSetKeyULong64Array3  ParserSetKeyULong64Array3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.10.1. Функция записывает трёхмерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyFloatArray3A(LPCSTR       szKey,      // Ключ.
                                       const PFLOAT a3fArray,   // Указатель на статический трёхмерный массив числовых значений типа FLOAT.
                                       const SIZE_T stSize1,    // Размер первого измерения массива.
                                       const SIZE_T stSize2,    // Размер второго измерения массива.
                                       const SIZE_T stSize3,    // Размер третьего измерения массива.
                                       const WORD   wDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.10.2. Функция записывает трёхмерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyFloatArray3W(LPCWSTR      szKey,      // Ключ.
                                       const PFLOAT a3fArray,   // Указатель на статический трёхмерный массив числовых значений типа FLOAT.
                                       const SIZE_T stSize1,    // Размер первого измерения массива.
                                       const SIZE_T stSize2,    // Размер второго измерения массива.
                                       const SIZE_T stSize3,    // Размер третьего измерения массива.
                                       const WORD   wDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.10.3. Функция записывает трёхмерный массив числовых значений ключа типа FLOAT. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyFloatArray3  ParserSetKeyFloatArray3W
#else
 #define ParserSetKeyFloatArray3  ParserSetKeyFloatArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.11.1. Функция записывает трёхмерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyDoubleArray3A(LPCSTR        szKey,      // Ключ.
                                        const PDOUBLE a3dArray,   // Указатель на статический трёхмерный массив числовых значений типа DOUBLE.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2,    // Размер второго измерения массива.
                                        const SIZE_T  stSize3,    // Размер третьего измерения массива.
                                        const INT     nDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.11.2. Функция записывает трёхмерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyDoubleArray3W(LPCWSTR       szKey,      // Ключ.
                                        const PDOUBLE a3dArray,   // Указатель на статический трёхмерный массив числовых значений типа DOUBLE.
                                        const SIZE_T  stSize1,    // Размер первого измерения массива.
                                        const SIZE_T  stSize2,    // Размер второго измерения массива.
                                        const SIZE_T  stSize3,    // Размер третьего измерения массива.
                                        const INT     nDecimals); // Отображаемое количество знаков после запятой.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.11.13. Функция записывает трёхмерный массив числовых значений ключа типа DOUBLE. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyDoubleArray3  ParserSetKeyDoubleArray3W
#else
 #define ParserSetKeyDoubleArray3  ParserSetKeyDoubleArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.12.1. Функция записывает трёхмерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyStringArray3A(LPCSTR       szKey,      // Ключ.
                                        LPCSTR*      a3szString, // Указатель на статический трёхмерный массив указателей на с-строки.
                                        const SIZE_T stSize1,    // Размер первого измерения массива.
                                        const SIZE_T stSize2,    // Размер второго измерения массива.
                                        const SIZE_T stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.12.2. Функция записывает трёхмерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyStringArray3W(LPCWSTR      szKey,      // Ключ.
                                        LPCWSTR*     a3szString, // Указатель на статический трёхмерный массив указателей на с-строки.
                                        const SIZE_T stSize1,    // Размер первого измерения массива.
                                        const SIZE_T stSize2,    // Размер второго измерения массива.
                                        const SIZE_T stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.12.3. Функция записывает трёхмерный массив c-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyStringArray3  ParserSetKeyStringArray3W
#else
 #define ParserSetKeyStringArray3  ParserSetKeyStringArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 5.6.13.1. Функция записывает трёхмерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с ANSI-строками.
EXPFUNC(VOID) ParserSetKeyStringArray3MA(LPCSTR             szKey,     // Ключ.
                                         const MT::PMQLSTRA a3SMqlStr, // Указатель на статический трёхмерный массив указателей на MQL-строки.
                                         const SIZE_T       stSize1,   // Размер первого измерения массива.
                                         const SIZE_T       stSize2,   // Размер второго измерения массива.
                                         const SIZE_T       stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.13.2. Функция записывает трёхмерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает с UNICODE-строками.
EXPFUNC(VOID) ParserSetKeyStringArray3MW(LPCWSTR            szKey,     // Ключ.
                                         const MT::PMQLSTRW a3SMqlStr, // Указатель на статический трёхмерный массив указателей на MQL-строки.
                                         const SIZE_T       stSize1,   // Размер первого измерения массива.
                                         const SIZE_T       stSize2,   // Размер второго измерения массива.
                                         const SIZE_T       stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 5.6.13.3. Функция записывает трёхмерный массив MQL-строковых значений ключа. Если ключа нет, то он будет дописан в конец текста. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserSetKeyStringArray3M  ParserSetKeyStringArray3MW
#else
 #define ParserSetKeyStringArray3M  ParserSetKeyStringArray3MA
#endif
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 6. ФУНКЦИИ ЧТЕНИЯ.
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж
// 6.1. Функции чтения чисел и строк.
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 6.1.1.1. Функция читает числовое значения ключа типа bool и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(bool) ParserGetKeyBoolA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.1.2. Функция читает числовое значения ключа типа bool и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(bool) ParserGetKeyBoolW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.1.3. Функция читает числовое значения ключа типа bool и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyBool  ParserGetKeyBoolW
#else
 #define ParserGetKeyBool  ParserGetKeyBoolA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.2.1. Функция читает числовое значения ключа типа CHAR и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(CHAR) ParserGetKeyCharA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.2.2. Функция читает числовое значения ключа типа CHAR и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(CHAR) ParserGetKeyCharW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.2.3. Функция читает числовое значения ключа типа CHAR и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyChar  ParserGetKeyCharW
#else
 #define ParserGetKeyChar  ParserGetKeyCharA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.3.1. Функция читает числовое значения ключа типа UCHAR и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(UCHAR) ParserGetKeyUCharA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.3.2. Функция читает числовое значения ключа типа UCHAR и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(UCHAR) ParserGetKeyUCharW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.3.3. Функция читает числовое значения ключа типа UCHAR и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUChar  ParserGetKeyUCharW
#else
 #define ParserGetKeyUChar  ParserGetKeyUCharA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.4.1. Функция читает числовое значения ключа типа SHORT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SHORT) ParserGetKeyShortA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.4.2. Функция читает числовое значения ключа типа SHORT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SHORT) ParserGetKeyShortW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.4.3. Функция читает числовое значения ключа типа SHORT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyShort  ParserGetKeyShortW
#else
 #define ParserGetKeyShort  ParserGetKeyShortA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.5.1. Функция читает числовое значения ключа типа USHORT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(USHORT) ParserGetKeyUShortA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.5.2. Функция читает числовое значения ключа типа USHORT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(USHORT) ParserGetKeyUShortW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.5.3. Функция читает числовое значения ключа типа USHORT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUShort  ParserGetKeyUShortW
#else
 #define ParserGetKeyUShort  ParserGetKeyUShortA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.6.1. Функция читает числовое значения ключа типа INT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(INT) ParserGetKeyIntA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.6.2. Функция читает числовое значения ключа типа INT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(INT) ParserGetKeyIntW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.6.3. Функция читает числовое значения ключа типа INT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyInt  ParserGetKeyIntW
#else
 #define ParserGetKeyInt  ParserGetKeyIntA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.7.1. Функция читает числовое значения ключа типа UINT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(UINT) ParserGetKeyUIntA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.7.2. Функция читает числовое значения ключа типа UINT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(UINT) ParserGetKeyUIntW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.7.3. Функция читает числовое значения ключа типа UINT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUInt  ParserGetKeyUIntW
#else
 #define ParserGetKeyUInt  ParserGetKeyUIntA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.8.1. Функция читает числовое значения ключа типа LONG64 и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(LONG64) ParserGetKeyLong64A(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.8.2. Функция читает числовое значения ключа типа LONG64 и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(LONG64) ParserGetKeyLong64W(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.8.3. Функция читает числовое значения ключа типа LONG64 и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyLong64  ParserGetKeyLong64W
#else
 #define ParserGetKeyLong64  ParserGetKeyLong64A
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.9.1. Функция читает числовое значения ключа типа ULONG64 и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(ULONG64) ParserGetKeyULong64A(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.9.2. Функция читает числовое значения ключа типа ULONG64 и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(ULONG64) ParserGetKeyULong64W(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.9.3. Функция читает числовое значения ключа типа ULONG64 и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyULong64  ParserGetKeyULong64W
#else
 #define ParserGetKeyULong64  ParserGetKeyULong64A
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.10.1. Функция читает числовое значения ключа типа FLOAT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(FLOAT) ParserGetKeyFloatA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.10.2. Функция читает числовое значения ключа типа FLOAT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(FLOAT) ParserGetKeyFloatW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.10.3. Функция читает числовое значения ключа типа FLOAT и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyFloat  ParserGetKeyFloatW
#else
 #define ParserGetKeyFloat  ParserGetKeyFloatA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.11.1. Функция читает числовое значения ключа типа DOUBLE и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(DOUBLE) ParserGetKeyDoubleA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.11.2. Функция читает числовое значения ключа типа DOUBLE и возвращает его. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(DOUBLE) ParserGetKeyDoubleW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.11.3. Функция читает числовое значения ключа типа DOUBLE и возвращает его. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyDouble  ParserGetKeyDoubleW
#else
 #define ParserGetKeyDouble  ParserGetKeyDoubleA
#endif
//==============================================================================================================================================================================================================================================================
// 6.1.12.1. Функция читает строковое значения ключа и возвращает его. Если ключа нет, то генерируется исключение. Функция работает с ANSI-строками.
EXPFUNC(LPSTR) ParserGetKeyStringA(LPCSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.12.2. Функция читает строковое значения ключа и возвращает его. Если ключа нет, то генерируется исключение. Функция работает с UNICODE-строками.
EXPFUNC(LPWSTR) ParserGetKeyStringW(LPCWSTR szKey); // Ключ.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.1.12.3. Функция читает строковое значения ключа и возвращает его. Если ключа нет, то генерируется исключение. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyString  ParserGetKeyStringW
#else
 #define ParserGetKeyString  ParserGetKeyStringA
#endif
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 6.2. Функции чтения одномерных массивов.
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 6.2.1.1. Функция читает в одномерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyBoolArrayA(LPCSTR       szKey,   // Ключ.
                                             pbool  abArray, // Указатель на статический одномерный массив логических значений типа bool.
                                       const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.1.2. Функция читает в одномерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyBoolArrayW(LPCWSTR      szKey,   // Ключ.
                                             pbool  abArray, // Указатель на статический одномерный массив логических значений типа bool.
                                       const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.1.3. Функция читает в одномерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyBoolArray  ParserGetKeyBoolArrayW
#else
 #define ParserGetKeyBoolArray  ParserGetKeyBoolArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.2.1. Функция читает в одномерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyCharArrayA(LPCSTR       szKey,   // Ключ.
                                             PCHAR  acArray, // Указатель на статический одномерный массив числовых значений типа CHAR.
                                       const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.2.2. Функция читает в одномерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyCharArrayW(LPCWSTR      szKey,   // Ключ.
                                             PCHAR  acArray, // Указатель на статический одномерный массив числовых значений типа CHAR.
                                       const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.2.3. Функция читает в одномерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyCharArray  ParserGetKeyCharArrayW
#else
 #define ParserGetKeyCharArray  ParserGetKeyCharArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.3.1. Функция читает в одномерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUCharArrayA(LPCSTR       szKey,    // Ключ.
                                              PUCHAR aucArray, // Указатель на статический одномерный массив числовых значений типа UCHAR.
                                        const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.3.2. Функция читает в одномерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUCharArrayW(LPCWSTR      szKey,    // Ключ.
                                              PUCHAR aucArray, // Указатель на статический одномерный массив числовых значений типа UCHAR.
                                        const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.3.3. Функция читает в одномерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUCharArray  ParserGetKeyUCharArrayW
#else
 #define ParserGetKeyUCharArray  ParserGetKeyUCharArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.4.1. Функция читает в одномерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyShortArrayA(LPCSTR       szKey,    // Ключ.
                                              PSHORT ashArray, // Указатель на статический одномерный массив числовых значений типа SHORT.
                                        const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.4.2. Функция читает в одномерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyShortArrayW(LPCWSTR      szKey,    // Ключ.
                                              PSHORT ashArray, // Указатель на статический одномерный массив числовых значений типа SHORT.
                                        const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.4.3. Функция читает в одномерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyShortArray  ParserGetKeyShortArrayW
#else
 #define ParserGetKeyShortArray  ParserGetKeyShortArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.5.1. Функция читает в одномерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUShortArrayA(LPCSTR        szKey,     // Ключ.
                                               PUSHORT aushArray, // Указатель на статический одномерный массив числовых значений типа USHORT.
                                         const SIZE_T  stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.5.2. Функция читает в одномерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUShortArrayW(LPCWSTR       szKey,     // Ключ.
                                               PUSHORT aushArray, // Указатель на статический одномерный массив числовых значений типа USHORT.
                                         const SIZE_T  stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.5.3. Функция читает в одномерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUShortArray  ParserGetKeyUShortArrayW
#else
 #define ParserGetKeyUShortArray  ParserGetKeyUShortArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.6.1. Функция читает в одномерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyIntArrayA(LPCSTR       szKey,   // Ключ.
                                            PINT   anArray, // Указатель на статический одномерный массив числовых значений типа INT.
                                      const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.6.2. Функция читает в одномерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyIntArrayW(LPCWSTR      szKey,   // Ключ.
                                            PINT   anArray, // Указатель на статический одномерный массив числовых значений типа INT.
                                      const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.6.3. Функция читает в одномерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyIntArray  ParserGetKeyIntArrayW
#else
 #define ParserGetKeyIntArray  ParserGetKeyIntArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.7.1. Функция читает в одномерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUIntArrayA(LPCSTR       szKey,    // Ключ.
                                             PUINT  auiArray, // Указатель на статический одномерный массив числовых значений типа UINT.
                                       const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.7.2. Функция читает в одномерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUIntArrayW(LPCWSTR      szKey,    // Ключ.
                                             PUINT  auiArray, // Указатель на статический одномерный массив числовых значений типа UINT.
                                       const SIZE_T stSize);  // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.7.3. Функция читает в одномерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUIntArray  ParserGetKeyUIntArrayW
#else
 #define ParserGetKeyUIntArray  ParserGetKeyUIntArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.8.1. Функция читает в одномерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyLong64ArrayA(LPCSTR        szKey,     // Ключ.
                                               PLONG64 al64Array, // Указатель на статический одномерный массив числовых значений типа LONG64.
                                         const SIZE_T  stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.8.2. Функция читает в одномерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyLong64ArrayW(LPCWSTR       szKey,    // Ключ.
                                               PLONG64 al64Array, // Указатель на статический одномерный массив числовых значений типа LONG64.
                                         const SIZE_T  stSize);   // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.8.3. Функция читает в одномерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyLong64Array  ParserGetKeyLong64ArrayW
#else
 #define ParserGetKeyLong64Array  ParserGetKeyLong64ArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.9.1. Функция читает в одномерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyULong64ArrayA(LPCSTR         szKey,      // Ключ.
                                                PULONG64 aul64Array, // Указатель на статический одномерный массив числовых значений типа ULONG64.
                                          const SIZE_T   stSize);    // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.9.2. Функция читает в одномерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyULong64ArrayW(LPCWSTR        szKey,      // Ключ.
                                                PULONG64 aul64Array, // Указатель на статический одномерный массив числовых значений типа ULONG64.
                                          const SIZE_T   stSize);    // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.9.3. Функция читает в одномерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyULong64Array  ParserGetKeyULong64ArrayW
#else
 #define ParserGetKeyULong64Array  ParserGetKeyULong64ArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.10.1. Функция читает в одномерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyFloatArrayA(LPCSTR       szKey,   // Ключ.
                                              PFLOAT afArray, // Указатель на статический одномерный массив числовых значений типа FLOAT.
                                        const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.10.2. Функция читает в одномерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyFloatArrayW(LPCWSTR      szKey,   // Ключ.
                                              PFLOAT afArray, // Указатель на статический одномерный массив числовых значений типа FLOAT.
                                        const SIZE_T stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.10.3. Функция читает в одномерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyFloatArray  ParserGetKeyFloatArrayW
#else
 #define ParserGetKeyFloatArray  ParserGetKeyFloatArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.11.1. Функция читает в одномерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyDoubleArrayA(LPCSTR        szKey,   // Ключ.
                                               PDOUBLE adArray, // Указатель на статический одномерный массив числовых значений типа DOUBLE.
                                         const SIZE_T  stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.11.2. Функция читает в одномерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyDoubleArrayW(LPCWSTR       szKey,   // Ключ.
                                               PDOUBLE adArray, // Указатель на статический одномерный массив числовых значений типа DOUBLE.
                                         const SIZE_T  stSize); // Размер массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.11.3. Функция читает в одномерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyDoubleArray  ParserGetKeyDoubleArrayW
#else
 #define ParserGetKeyDoubleArray  ParserGetKeyDoubleArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.12.1. Функция читает в одномерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArrayA(LPCSTR       szKey,     // Ключ.
                                               LPSTR* aszString, // Указатель на статический одномерный массив указателей на с-строки.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2);  // Размер второго измерения массива (максимальная длина строки).
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.12.2. Функция читает в одномерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArrayW(LPCWSTR       szKey,     // Ключ.
                                               LPWSTR* aszString, // Указатель на статический одномерный массив указателей на с-строки.
                                         const SIZE_T  stSize1,   // Размер первого измерения массива.
                                         const SIZE_T  stSize2);  // Размер второго измерения массива (максимальная длина строки).
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.12.3. Функция читает в одномерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyStringArray  ParserGetKeyStringArrayW
#else
 #define ParserGetKeyStringArray  ParserGetKeyStringArrayA
#endif
//==============================================================================================================================================================================================================================================================
// 6.2.13.1. Функция читает в одномерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArrayMA(LPCSTR             szKey,    // Ключ.
                                                MT::PMQLSTRA aSMqlStr, // Указатель на статический одномерный массив указателей на MQL-строки.
                                          const SIZE_T       stSize);  // Размер первого измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.13.2. Функция читает в одномерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArrayMW(LPCWSTR            szKey,    // Ключ.
                                                MT::PMQLSTRW aSMqlStr, // Указатель на статический одномерный массив указателей на MQL-строки.
                                          const SIZE_T       stSize);  // Размер первого измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.2.13.3. Функция читает в одномерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyStringArrayM  ParserGetKeyStringArrayMW
#else
 #define ParserGetKeyStringArrayM  ParserGetKeyStringArrayMA
#endif
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 6.3. Функции чтения двухмерных массивов.
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 6.3.1.1. Функция читает в двухмерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyBoolArray2A(LPCSTR       szKey,    // Ключ.
                                              pbool  a2bArray, // Указатель на статический двухмерный массив логических значений типа bool.
                                        const SIZE_T stSize1,  // Размер первого измерения массива.
                                        const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.1.2. Функция читает в двухмерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyBoolArray2W(LPCWSTR      szKey,    // Ключ.
                                              pbool  a2bArray, // Указатель на статический двухмерный массив логических значений типа bool.
                                        const SIZE_T stSize1,  // Размер первого измерения массива.
                                        const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.1.3. Функция читает в двухмерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyBoolArray2  ParserGetKeyBoolArray2W
#else
 #define ParserGetKeyBoolArray2  ParserGetKeyBoolArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.2.1. Функция читает в двухмерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyCharArray2A(LPCSTR       szKey,    // Ключ.
                                              PCHAR  a2cArray, // Указатель на статический двухмерный массив числовых значений типа CHAR.
                                        const SIZE_T stSize1,  // Размер первого измерения массива.
                                        const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.2.2. Функция читает в двухмерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyCharArray2W(LPCWSTR      szKey,    // Ключ.
                                              PCHAR  a2cArray, // Указатель на статический двухмерный массив числовых значений типа CHAR.
                                        const SIZE_T stSize1,  // Размер первого измерения массива.
                                        const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.2.3. Функция читает в двухмерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyCharArray2  ParserGetKeyCharArray2W
#else
 #define ParserGetKeyCharArray2  ParserGetKeyCharArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.3.1. Функция читает в двухмерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUCharArray2A(LPCSTR       szKey,     // Ключ.
                                               PUCHAR a2ucArray, // Указатель на статический двухмерный массив числовых значений типа UCHAR.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.3.2. Функция читает в двухмерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUCharArray2W(LPCWSTR      szKey,     // Ключ.
                                               PUCHAR a2ucArray, // Указатель на статический двухмерный массив числовых значений типа UCHAR.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.3.3. Функция читает в двухмерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUCharArray2  ParserGetKeyUCharArray2W
#else
 #define ParserGetKeyUCharArray2  ParserGetKeyUCharArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.4.1. Функция читает в двухмерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyShortArray2A(LPCSTR       szKey,     // Ключ.
                                               PSHORT a2shArray, // Указатель на статический двухмерный массив числовых значений типа SHORT.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.4.2. Функция читает в двухмерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyShortArray2W(LPCWSTR      szKey,     // Ключ.
                                               PSHORT a2shArray, // Указатель на статический двухмерный массив числовых значений типа SHORT.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.4.3. Функция читает в двухмерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyShortArray2  ParserGetKeyShortArray2W
#else
 #define ParserGetKeyShortArray2  ParserGetKeyShortArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.5.1. Функция читает в двухмерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUShortArray2A(LPCSTR        szKey,      // Ключ.
                                                PUSHORT a2ushArray, // Указатель на статический двухмерный массив числовых значений типа USHORT.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.5.2. Функция читает в двухмерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUShortArray2W(LPCWSTR       szKey,      // Ключ.
                                                PUSHORT a2ushArray, // Указатель на статический двухмерный массив числовых значений типа USHORT.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.5.3. Функция читает в двухмерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUShortArray2  ParserGetKeyUShortArray2W
#else
 #define ParserGetKeyUShortArray2  ParserGetKeyUShortArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.6.1. Функция читает в двухмерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyIntArray2A(LPCSTR       szKey,    // Ключ.
                                             PINT   a2nArray, // Указатель на статический двухмерный массив числовых значений типа INT.
                                       const SIZE_T stSize1,  // Размер первого измерения массива.
                                       const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.6.2. Функция читает в двухмерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyIntArray2W(LPCWSTR      szKey,    // Ключ.
                                             PINT   a2nArray, // Указатель на статический двухмерный массив числовых значений типа INT.
                                       const SIZE_T stSize1,  // Размер первого измерения массива.
                                       const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.6.3. Функция читает в двухмерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyIntArray2  ParserGetKeyIntArray2W
#else
 #define ParserGetKeyIntArray2  ParserGetKeyIntArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.7.1. Функция читает в двухмерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUIntArray2A(LPCSTR       szKey,     // Ключ.
                                              PUINT  a2uiArray, // Указатель на статический двухмерный массив числовых значений типа UINT.
                                        const SIZE_T stSize1,   // Размер первого измерения массива.
                                        const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.7.2. Функция читает в двухмерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUIntArray2W(LPCWSTR      szKey,     // Ключ.
                                              PUINT  a2uiArray, // Указатель на статический двухмерный массив числовых значений типа UINT.
                                        const SIZE_T stSize1,   // Размер первого измерения массива.
                                        const SIZE_T stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.7.3. Функция читает в двухмерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUIntArray2  ParserGetKeyUIntArray2W
#else
 #define ParserGetKeyUIntArray2  ParserGetKeyUIntArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.8.1. Функция читает в двухмерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyLong64Array2A(LPCSTR        szKey,      // Ключ.
                                                PLONG64 a2l64Array, // Указатель на статический двухмерный массив числовых значений типа LONG64.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.8.2. Функция читает в двухмерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyLong64Array2W(LPCWSTR       szKey,      // Ключ.
                                                PLONG64 a2l64Array, // Указатель на статический двухмерный массив числовых значений типа LONG64.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2);   // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.8.3. Функция читает в двухмерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyLong64Array2  ParserGetKeyLong64Array2W
#else
 #define ParserGetKeyLong64Array2  ParserGetKeyLong64Array2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.9.1. Функция читает в двухмерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyULong64Array2A(LPCSTR         szKey,       // Ключ.
                                                 PULONG64 a2ul64Array, // Указатель на статический двухмерный массив числовых значений типа ULONG64.
                                           const SIZE_T   stSize1,     // Размер первого измерения массива.
                                           const SIZE_T   stSize2);    // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.9.2. Функция читает в двухмерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyULong64Array2W(LPCWSTR        szKey,       // Ключ.
                                                 PULONG64 a2ul64Array, // Указатель на статический двухмерный массив числовых значений типа ULONG64.
                                           const SIZE_T   stSize1,     // Размер первого измерения массива.
                                           const SIZE_T   stSize2);    // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.9.3. Функция читает в двухмерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyULong64Array2  ParserGetKeyULong64Array2W
#else
 #define ParserGetKeyULong64Array2  ParserGetKeyULong64Array2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.10.1. Функция читает в двухмерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyFloatArray2A(LPCSTR       szKey,    // Ключ.
                                               PFLOAT a2fArray, // Указатель на статический двухмерный массив числовых значений типа FLOAT.
                                         const SIZE_T stSize1,  // Размер первого измерения массива.
                                         const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.10.2. Функция читает в двухмерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyFloatArray2W(LPCWSTR      szKey,    // Ключ.
                                               PFLOAT a2fArray, // Указатель на статический двухмерный массив числовых значений типа FLOAT.
                                         const SIZE_T stSize1,  // Размер первого измерения массива.
                                         const SIZE_T stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.10.3. Функция читает в двухмерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyFloatArray2  ParserGetKeyFloatArray2W
#else
 #define ParserGetKeyFloatArray2  ParserGetKeyFloatArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.11.1. Функция читает в двухмерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyDoubleArray2A(LPCSTR        szKey,    // Ключ.
                                                PDOUBLE a2dArray, // Указатель на статический двухмерный массив числовых значений типа DOUBLE.
                                          const SIZE_T  stSize1,  // Размер первого измерения массива.
                                          const SIZE_T  stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.11.2. Функция читает в двухмерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyDoubleArray2W(LPCWSTR       szKey,    // Ключ.
                                                PDOUBLE a2dArray, // Указатель на статический двухмерный массив числовых значений типа DOUBLE.
                                          const SIZE_T  stSize1,  // Размер первого измерения массива.
                                          const SIZE_T  stSize2); // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.11.3. Функция читает в двухмерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyDoubleArray2  ParserGetKeyDoubleArray2W
#else
 #define ParserGetKeyDoubleArray2  ParserGetKeyDoubleArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.12.1. Функция читает в двухмерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArray2A(LPCSTR       szKey,      // Ключ.
                                                LPSTR* a2szString, // Указатель на статический двухмерный массив указателей на с-строки.
                                          const SIZE_T stSize1,    // Размер первого измерения массива.
                                          const SIZE_T stSize2,    // Размер второго измерения массива.
                                          const SIZE_T stSize3);   // Размер третьего измерения массива (максимальная длина строки).
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.12.2. Функция читает в двухмерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArray2W(LPCWSTR       szKey,      // Ключ.
                                                LPWSTR* a2szString, // Указатель на статический двухмерный массив указателей на с-строки.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2,    // Размер второго измерения массива.
                                          const SIZE_T  stSize3);   // Размер третьего измерения массива (максимальная длина строки).
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.12.3. Функция читает в двухмерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyStringArray2  ParserGetKeyStringArray2W
#else
 #define ParserGetKeyStringArray2  ParserGetKeyStringArray2A
#endif
//==============================================================================================================================================================================================================================================================
// 6.3.13.1. Функция читает в двухмерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArray2MA(LPCSTR             szKey,     // Ключ.
                                                 MT::PMQLSTRA a2SMqlStr, // Указатель на статический двухмерный массив указателей на MQL-строки.
                                           const SIZE_T       stSize1,   // Размер первого измерения массива.
                                           const SIZE_T       stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.13.2. Функция читает в двухмерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArray2MW(LPCWSTR            szKey,     // Ключ.
                                                 MT::PMQLSTRW a2SMqlStr, // Указатель на статический двухмерный массив указателей на MQL-строки.
                                           const SIZE_T       stSize1,   // Размер первого измерения массива.
                                           const SIZE_T       stSize2);  // Размер второго измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.3.13.3. Функция читает в двухмерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyStringArray2M  ParserGetKeyStringArray2MW
#else
 #define ParserGetKeyStringArray2M  ParserGetKeyStringArray2MA
#endif
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 6.4. Функции чтения трёхмерных массивов.
//xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
// 6.4.1.1. Функция читает в трёхмерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyBoolArray3A(LPCSTR       szKey,    // Ключ.
                                              pbool  a3bArray, // Указатель на статический трёхмерный массив логических значений типа bool.
                                        const SIZE_T stSize1,  // Размер первого измерения массива.
                                        const SIZE_T stSize2,  // Размер второго измерения массива.
                                        const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.1.2. Функция читает в трёхмерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyBoolArray3W(LPCWSTR      szKey,    // Ключ.
                                              pbool  a3bArray, // Указатель на статический трёхмерный массив логических значений типа bool.
                                        const SIZE_T stSize1,  // Размер первого измерения массива.
                                        const SIZE_T stSize2,  // Размер второго измерения массива.
                                        const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.1.3. Функция читает в трёхмерный массив числовые значения ключа типа bool. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyBoolArray3  ParserGetKeyBoolArray3W
#else
 #define ParserGetKeyBoolArray3  ParserGetKeyBoolArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.2.1. Функция читает в трёхмерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyCharArray3A(LPCSTR       szKey,    // Ключ.
                                              PCHAR  a3cArray, // Указатель на статический трёхмерный массив числовых значений типа CHAR.
                                        const SIZE_T stSize1,  // Размер первого измерения массива.
                                        const SIZE_T stSize2,  // Размер второго измерения массива.
                                        const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.2.2. Функция читает в трёхмерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyCharArray3W(LPCWSTR      szKey,    // Ключ.
                                              PCHAR  a3cArray, // Указатель на статический трёхмерный массив числовых значений типа CHAR.
                                        const SIZE_T stSize1,  // Размер первого измерения массива.
                                        const SIZE_T stSize2,  // Размер второго измерения массива.
                                        const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.2.3. Функция читает в трёхмерный массив числовые значения ключа типа CHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyCharArray3  ParserGetKeyCharArray3W
#else
 #define ParserGetKeyCharArray3  ParserGetKeyCharArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.3.1. Функция читает в трёхмерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUCharArray3A(LPCSTR       szKey,     // Ключ.
                                               PUCHAR a3ucArray, // Указатель на статический трёхмерный массив числовых значений типа UCHAR.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2,   // Размер второго измерения массива.
                                         const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.3.2. Функция читает в трёхмерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUCharArray3W(LPCWSTR      szKey,     // Ключ.
                                               PUCHAR a3ucArray, // Указатель на статический трёхмерный массив числовых значений типа UCHAR.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2,   // Размер второго измерения массива.
                                         const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.3.3. Функция читает в трёхмерный массив числовые значения ключа типа UCHAR. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUCharArray3  ParserGetKeyUCharArray3W
#else
 #define ParserGetKeyUCharArray3  ParserGetKeyUCharArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.4.1. Функция читает в трёхмерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyShortArray3A(LPCSTR       szKey,     // Ключ.
                                               PSHORT a3shArray, // Указатель на статический трёхмерный массив числовых значений типа SHORT.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2,   // Размер второго измерения массива.
                                         const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.4.2. Функция читает в трёхмерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyShortArray3W(LPCWSTR      szKey,     // Ключ.
                                               PSHORT a3shArray, // Указатель на статический трёхмерный массив числовых значений типа SHORT.
                                         const SIZE_T stSize1,   // Размер первого измерения массива.
                                         const SIZE_T stSize2,   // Размер второго измерения массива.
                                         const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.4.3. Функция читает в трёхмерный массив числовые значения ключа типа SHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyShortArray3  ParserGetKeyShortArray3W
#else
 #define ParserGetKeyShortArray3  ParserGetKeyShortArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.5.1. Функция читает в трёхмерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUShortArray3A(LPCSTR        szKey,      // Ключ.
                                                PUSHORT a3ushArray, // Указатель на статический трёхмерный массив числовых значений типа USHORT.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2,    // Размер второго измерения массива.
                                          const SIZE_T  stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.5.2. Функция читает в трёхмерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUShortArray3W(LPCWSTR       szKey,      // Ключ.
                                                PUSHORT a3ushArray, // Указатель на статический трёхмерный массив числовых значений типа USHORT.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2,    // Размер второго измерения массива.
                                          const SIZE_T  stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.5.3. Функция читает в трёхмерный массив числовые значения ключа типа USHORT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUShortArray3  ParserGetKeyUShortArray3W
#else
 #define ParserGetKeyUShortArray3  ParserGetKeyUShortArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.6.1. Функция читает в трёхмерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyIntArray3A(LPCSTR       szKey,    // Ключ.
                                             PINT   a3nArray, // Указатель на статический трёхмерный массив числовых значений типа INT.
                                       const SIZE_T stSize1,  // Размер первого измерения массива.
                                       const SIZE_T stSize2,  // Размер второго измерения массива.
                                       const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.6.2. Функция читает в трёхмерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyIntArray3W(LPCWSTR      szKey,    // Ключ.
                                             PINT   a3nArray, // Указатель на статический трёхмерный массив числовых значений типа INT.
                                       const SIZE_T stSize1,  // Размер первого измерения массива.
                                       const SIZE_T stSize2,  // Размер второго измерения массива.
                                       const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.6.3. Функция читает в трёхмерный массив числовые значения ключа типа INT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyIntArray3  ParserGetKeyIntArray3W
#else
 #define ParserGetKeyIntArray3  ParserGetKeyIntArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.7.1. Функция читает в трёхмерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyUIntArray3A(LPCSTR       szKey,     // Ключ.
                                              PUINT  a3uiArray, // Указатель на статический трёхмерный массив числовых значений типа UINT.
                                        const SIZE_T stSize1,   // Размер первого измерения массива.
                                        const SIZE_T stSize2,   // Размер второго измерения массива.
                                        const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.7.2. Функция читает в трёхмерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyUIntArray3W(LPCWSTR      szKey,     // Ключ.
                                              PUINT  a3uiArray, // Указатель на статический трёхмерный массив числовых значений типа UINT.
                                        const SIZE_T stSize1,   // Размер первого измерения массива.
                                        const SIZE_T stSize2,   // Размер второго измерения массива.
                                        const SIZE_T stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.7.3. Функция читает в трёхмерный массив числовые значения ключа типа UINT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyUIntArray3  ParserGetKeyUIntArray3W
#else
 #define ParserGetKeyUIntArray3  ParserGetKeyUIntArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.8.1. Функция читает в трёхмерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyLong64Array3A(LPCSTR        szKey,      // Ключ.
                                                PLONG64 a3l64Array, // Указатель на статический трёхмерный массив числовых значений типа LONG64.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2,    // Размер второго измерения массива.
                                          const SIZE_T  stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.8.2. Функция читает в трёхмерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyLong64Array3W(LPCWSTR       szKey,      // Ключ.
                                                PLONG64 a3l64Array, // Указатель на статический трёхмерный массив числовых значений типа LONG64.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2,    // Размер второго измерения массива.
                                          const SIZE_T  stSize3);   // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.8.3. Функция читает в трёхмерный массив числовые значения ключа типа LONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyLong64Array3  ParserGetKeyLong64Array3W
#else
 #define ParserGetKeyLong64Array3  ParserGetKeyLong64Array3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.9.1. Функция читает в трёхмерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyULong64Array3A(LPCSTR         szKey,       // Ключ.
                                                 PULONG64 a3ul64Array, // Указатель на статический трёхмерный массив числовых значений типа ULONG64.
                                           const SIZE_T   stSize1,     // Размер первого измерения массива.
                                           const SIZE_T   stSize2,     // Размер второго измерения массива.
                                           const SIZE_T   stSize3);    // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.9.2. Функция читает в трёхмерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyULong64Array3W(LPCWSTR        szKey,       // Ключ.
                                                 PULONG64 a3ul64Array, // Указатель на статический трёхмерный массив числовых значений типа ULONG64.
                                           const SIZE_T   stSize1,     // Размер первого измерения массива.
                                           const SIZE_T   stSize2,     // Размер второго измерения массива.
                                           const SIZE_T   stSize3);    // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.9.3. Функция читает в трёхмерный массив числовые значения ключа типа ULONG64. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyULong64Array3  ParserGetKeyULong64Array3W
#else
 #define ParserGetKeyULong64Array3  ParserGetKeyULong64Array3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.10.1. Функция читает в трёхмерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyFloatArray3A(LPCSTR       szKey,    // Ключ.
                                               PFLOAT a3fArray, // Указатель на статический трёхмерный массив числовых значений типа FLOAT.
                                         const SIZE_T stSize1,  // Размер первого измерения массива.
                                         const SIZE_T stSize2,  // Размер второго измерения массива.
                                         const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.10.2. Функция читает в трёхмерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyFloatArray3W(LPCWSTR      szKey,    // Ключ.
                                               PFLOAT a3fArray, // Указатель на статический трёхмерный массив числовых значений типа FLOAT.
                                         const SIZE_T stSize1,  // Размер первого измерения массива.
                                         const SIZE_T stSize2,  // Размер второго измерения массива.
                                         const SIZE_T stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.10.3. Функция читает в трёхмерный массив числовые значения ключа типа FLOAT. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyFloatArray3  ParserGetKeyFloatArray3W
#else
 #define ParserGetKeyFloatArray3  ParserGetKeyFloatArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.11.1. Функция читает в трёхмерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyDoubleArray3A(LPCSTR        szKey,    // Ключ.
                                                PDOUBLE a3dArray, // Указатель на статический трёхмерный массив числовых значений типа DOUBLE.
                                          const SIZE_T  stSize1,  // Размер первого измерения массива.
                                          const SIZE_T  stSize2,  // Размер второго измерения массива.
                                          const SIZE_T  stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.11.2. Функция читает в трёхмерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyDoubleArray3W(LPCWSTR       szKey,    // Ключ.
                                                PDOUBLE a3dArray, // Указатель на статический трёхмерный массив числовых значений типа DOUBLE.
                                          const SIZE_T  stSize1,  // Размер первого измерения массива.
                                          const SIZE_T  stSize2,  // Размер второго измерения массива.
                                          const SIZE_T  stSize3); // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.11.3. Функция читает в трёхмерный массив числовые значения ключа типа DOUBLE. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyDoubleArray3  ParserGetKeyDoubleArray3W
#else
 #define ParserGetKeyDoubleArray3  ParserGetKeyDoubleArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.12.1. Функция читает в трёхмерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArray3A(LPCSTR       szKey,      // Ключ.
                                                LPSTR* a3szString, // Указатель на статический трёхмерный массив указателей на с-строки.
                                          const SIZE_T stSize1,    // Размер первого измерения массива.
                                          const SIZE_T stSize2,    // Размер второго измерения массива.
                                          const SIZE_T stSize3,    // Размер третьего измерения массива.
                                          const SIZE_T stSize4);   // Размер четвёртого измерения массива (максимальная длина строки).
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.12.2. Функция читает в трёхмерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArray3W(LPCWSTR       szKey,      // Ключ.
                                                LPWSTR* a3szString, // Указатель на статический трёхмерный массив указателей на с-строки.
                                          const SIZE_T  stSize1,    // Размер первого измерения массива.
                                          const SIZE_T  stSize2,    // Размер второго измерения массива.
                                          const SIZE_T  stSize3,    // Размер третьего измерения массива.
                                          const SIZE_T  stSize4);   // Размер четвёртого измерения массива (максимальная длина строки).
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.12.3. Функция читает в трёхмерный массив c-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyStringArray3  ParserGetKeyStringArray3W
#else
 #define ParserGetKeyStringArray3  ParserGetKeyStringArray3A
#endif
//==============================================================================================================================================================================================================================================================
// 6.4.13.1. Функция читает в трёхмерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с ANSI-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArray3MA(LPCSTR             szKey,     // Ключ.
                                                 MT::PMQLSTRA a3SMqlStr, // Указатель на статический трёхмерный массив указателей на MQL-строки.
                                           const SIZE_T       stSize1,   // Размер первого измерения массива.
                                           const SIZE_T       stSize2,   // Размер второго измерения массива.
                                           const SIZE_T       stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.13.2. Функция читает в трёхмерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает с UNICODE-строками.
EXPFUNC(SIZE_T) ParserGetKeyStringArray3MW(LPCWSTR            szKey,     // Ключ.
                                                 MT::PMQLSTRW a3SMqlStr, // Указатель на статический трёхмерный массив указателей на MQL-строки.
                                           const SIZE_T       stSize1,   // Размер первого измерения массива.
                                           const SIZE_T       stSize2,   // Размер второго измерения массива.
                                           const SIZE_T       stSize3);  // Размер третьего измерения массива.
//--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
// 6.4.13.3. Функция читает в трёхмерный массив MQL-строковые значения ключа. Функция возвращает количество прочитанных значений. Если ключа нет, то возвращается ноль. Функция работает со строками текущей кодировки проекта.
#if defined(UNICODE) || defined(_UNICODE)
 #define ParserGetKeyStringArray3M  ParserGetKeyStringArray3MW
#else
 #define ParserGetKeyStringArray3M  ParserGetKeyStringArray3MA
#endif
//жжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжжж